import netCDF4
import numpy as np
import matplotlib.pyplot as plt
import pyresample as pr
from lightningcast import utils
import sys
from datetime import datetime

# nlat = 21600 ;
# nlon = 43200

elevfile = "/data/common/STATIC_SURFACE_DATA/GLOBE_1km_digelev.hdf"
nc = netCDF4.Dataset(elevfile, "r")
elev = nc.variables["surface_elevation"][4000:10000, 5500:15000]  # in m
dlat = nc.dlat
dlon = nc.dlon
first_lat = nc.first_lat
first_lon = nc.first_lon
nc.close()

nlat, nlon = elev.shape

lats = np.arange(first_lat, -first_lat, -dlat)
lats = lats[4000:10000]
# lons = np.arange(first_lon,360,dlon)
lons = np.arange(first_lon, 180, dlon)
lons = lons[5500:15000]
# lons[lons > 180] = lons[lons > 180] - 360

lons2D, lats2D = np.meshgrid(lons, lats)
old_grid = pr.geometry.GridDefinition(lons=lons2D, lats=lats2D)

new_def, _, _, x, y = utils.get_area_definition("static/GOES_East.nc", return_xy=True)
r_elev = pr.kd_tree.resample_nearest(
    old_grid, elev, new_def, radius_of_influence=10000, fill_value=-999
)

dims = {"x": 2500, "y": 1500}

datasets = {}
datasets["surface_elevation"] = {
    "data": r_elev,
    "dims": ("y", "x"),
    "atts": {
        "desc": "surface elevation remapped to 2-km GOES-East CONUS fixed grid",
        "units": "meters",
    },
}
datasets["x"] = {
    "data": x,
    "dims": ("x"),
    "atts": {
        "desc": "projection x coordinates (i.e., already multiplied by sat height)"
    },
}
datasets["y"] = {
    "data": y,
    "dims": ("y"),
    "atts": {
        "desc": "projection y coordinates (i.e., already multiplied by sat height)"
    },
}

global_atts = {"creation_date": datetime.utcnow().strftime("%Y-%m-%d %H:%M UTC")}

outfile = "/home/jcintineo/lightningcast/src/surface_GOES-East_elevation.nc"
utils.write_netcdf(outfile, datasets, dims, atts=global_atts)
