import numpy as np
import pyresample as pr
import matplotlib.pyplot as plt
import netCDF4
from lightningcast import utils
import os, sys

varname = "HRAC_COM_FR"  #'LRADC_COM_SMFR' #'HRAC_COM_FR'
# filename = '/home/jcintineo/LISOTD_LRADC_V2.3.2015.nc' #lats/lons every 2.5 deg
filename = "/home/jcintineo/LISOTD_HRAC_V2.3.2015.nc"  # lats/lons every 0.5 deg
ROI = 60000  # 240000 for LRADC_COM_SMFR; 60000 for HRAC_COM_FR
outDiv = 4  # 20 for LRADC_COM_SMFR; 4 for HRAC_COM_FR

datasets = {
    varname: {"atts": ["ALL"]},
    "Latitude": {"atts": ["ALL"]},
    "Longitude": {"atts": ["ALL"]},
}
if varname == "LRADC_COM_SMFR":
    datasets["UTC_Hour"] = {"atts": ["ALL"]}

utils.read_netcdf(filename, datasets)

ltgdens = datasets[varname]["data"]
lats = datasets["Latitude"]["data"]
lons = datasets["Longitude"]["data"]
try:
    UTC_hour = datasets["UTC_Hour"]["data"]
except (NameError, KeyError):
    pass

################################################

lons, lats = np.meshgrid(lons, lats)
climoGridDef = pr.geometry.GridDefinition(lons=lons, lats=lats)

geoAreaDef, ny, nx = utils.get_area_definition(
    f'{os.environ["PLTG"]}/src/static/GOES_East.nc',
    outny=1500 // outDiv,
    outnx=2500 // outDiv,
)

ndays = 365
hours = 6
if varname == "HRAC_COM_FR":
    newdata = np.zeros(shape=(ndays, ny, nx), dtype=np.float32)
else:
    newdata = np.zeros(shape=(ndays, hours, ny, nx), dtype=np.float32)

for ii in range(ndays):
    print(ii)
    if varname == "HRAC_COM_FR":
        newdata[ii] = pr.kd_tree.resample_nearest(
            climoGridDef,
            ltgdens[..., ii],
            geoAreaDef,
            radius_of_influence=ROI,
            fill_value=-1,
        )
    else:
        for jj in range(hours):
            newdata[ii, jj] = pr.kd_tree.resample_nearest(
                climoGridDef,
                ltgdens[..., jj, ii],
                geoAreaDef,
                radius_of_influence=ROI,
                fill_value=-1,
            )

dims = {"ny": ny, "nx": nx, "day_of_year": ndays}
if varname != "HRAC_COM_FR":
    dims["hour"] = hours

ltg_atts = datasets[varname]["atts"]

outdatasets = {}
if varname == "HRAC_COM_FR":
    outdatasets[varname] = {
        "data": newdata,
        "dims": ("day_of_year", "ny", "nx"),
        "atts": ltg_atts,
    }
else:
    outdatasets[varname] = {
        "data": newdata,
        "dims": ("day_of_year", "hour", "ny", "nx"),
        "atts": ltg_atts,
    }
    UTC_atts = datasets["UTC_Hour"]["atts"]
    outdatasets["UTC_Hour"] = {"data": UTC_hour, "dims": ("hour"), "atts": UTC_atts}


outfile = f'{os.environ["PWD"]}/ltg_climo_daily.nc'
utils.write_netcdf(outfile, outdatasets, dims)
