import os

os.environ[
    "SATPY_CONFIG_PATH"
] = "/home/jcintineo/probsevere_oconus/src/satpy_plotting/SATPY_CONFIG/"

from datetime import datetime, timedelta
import time
import glob
import numpy as np
import shutil
from satpy import Scene
import pyresample as pr
from pyproj import Proj
from netCDF4 import Dataset
import pygrib as pg
import sys

sys.path.insert(0, "../")
import solar_angles
import cartopy.crs as ccrs
import cartopy.feature as cfeature
import matplotlib

matplotlib.use("Agg")
import matplotlib.pyplot as plt
from satpy.writers import get_enhanced_image
import xarray
import traceback
import utils
import pickle


def create_rgb(abi_filenames, outdir, glmfile=None):
    dt = datetime.strptime(
        os.path.basename(abi_filenames[0]).split("_s")[-1][0:11], "%Y%j%H%M"
    )

    ###Scene definition and cropping
    scn = Scene(reader="abi_l1b", filenames=abi_filenames)
    scn.load(
        ["C13", "C15", "C11", "C14", "C02", "C05"],
        calibration=[
            "brightness_temperature",
            "brightness_temperature",
            "brightness_temperature",
            "brightness_temperature",
            "reflectance",
            "reflectance",
        ],
    )

    DCPfilepath = dt.strftime("goes16_DCP_%Y_%m_%d_%H_%M_%j.png")
    scn.load(["DayCloudPhaseFC"])
    scn.load(["IRCloudPhaseFC"])

    resamp = scn.resample(scn.coarsest_area(), resampler="native")
    fig = plt.figure(figsize=(12, 9))
    rgb_data = get_enhanced_image(resamp["IRCloudPhaseFC"]).data

    op = rgb_data.orbital_parameters
    pyproj_obj = Proj(
        proj="geos",
        h=op["projection_altitude"],
        lon_0=op["projection_longitude"],
        sweep="x",
    )
    geoproj = ccrs.Geostationary(
        central_longitude=op["projection_longitude"],
        sweep_axis="x",
        satellite_height=op["projection_altitude"],
    )

    x = rgb_data.x
    y = rgb_data.y

    centerlon, centerlat = pyproj_obj(x[len(x) // 2], y[len(y) // 2], inverse=True)
    mean_solzen, mean_solaz = solar_angles.solar_angles(
        dt, lat=centerlat, lon=centerlon
    )
    mean_solzen = mean_solzen[0]

    if mean_solzen > 88:
        rgb_data = get_enhanced_image(resamp["IRCloudPhaseFC"]).data
    else:
        rgb_data = get_enhanced_image(resamp["DayCloudPhaseFC"]).data

    ax = fig.add_axes([0, 0, 1, 1], projection=geoproj)
    rgb_data.plot.imshow(rgb="bands", ax=ax, transform=geoproj)

    if glmfile:
        nc = Dataset(glmfile, "r")
        fed = nc["FED_accum_60min_2km"][:]
        nc.close()
        contour_img = ax.contour(x, y, fed, [0.5], colors=["white"], linewidths=[0.5])

    state_borders = cfeature.NaturalEarthFeature(
        category="cultural",
        name="admin_1_states_provinces_lakes",
        scale="50m",
        facecolor="none",
    )
    ax.add_feature(state_borders, edgecolor="black", linewidth=0.5)
    ax.coastlines(edgecolor="black", linewidth=0.5)
    text = plt.text(
        0.0,
        0.98,
        dt.strftime("GOES-16  %Y.%m.%d-%H.%M UTC"),
        fontsize=14,
        transform=ax.transAxes,
        backgroundcolor="black",
        color="yellow",
    )
    plt.axis("off")
    plt.title("")

    utils.mkdir_p(dt.strftime(f"{outdir}/%Y%m%d/"))
    plt.savefig(
        dt.strftime(f"{outdir}/%Y%m%d/goes16_%Y%m%d-%H%M.png"), bbox_inches="tight"
    )
    # resamp.save_dataset(writer='simple_image', tiled=True, dataset_id='DayCloudPhaseFC', filename=DCPfilepath)
    sys.exit()


if __name__ == "__main__":

    abidir = "/arcdata/goes/grb/goes16/"
    # dt = datetime(2019,7,1,14,6)
    # outdir=os.environ['PWD']
    outdir = "/apollo/grain/jcintineo/AI/OCONUS/rgb_quicklooks/"

    dictlist = pickle.load(open("../samplelists/validation/val_2.5%.pkl", "rb"))
    uniq_dictlist = []
    uniq_dts = []
    for dl in dictlist:
        if dl["abidt"] not in uniq_dts:
            uniq_dictlist.append(dl)
            uniq_dts.append(dl["abidt"])

    print(len(uniq_dts))
    sys.exit()

    for udict in uniq_dictlist:
        dt = udict["abidt"]

        filenames = glob.glob(
            dt.strftime(f"{abidir}/%Y/%Y_%m_%d_%j/abi/L1b/RadC/*_s%Y%j%H%M*")
        )

        create_rgb(filenames, outdir=outdir, glmfile=udict["target_file"])
        # sys.exit()
