import numpy as np
import matplotlib.pyplot as plt

# goes east conus

# CSI = [0.4543, 0.2572, 0.3238, 0.4015, 0.5259, 0.4286, 0.5037, 0.5095, 0.4584, 0.3646, 0.2341, 0.3222]
CSIday = [
    0.4537,
    0.3969,
    0.3506,
    0.4220,
    0.5301,
    0.4256,
    0.5112,
    0.5121,
    0.4690,
    0.3521,
    0.2495,
    0.2972,
]
CSInight = [
    0.4547,
    0.3786,
    0.3061,
    0.3913,
    0.5239,
    0.4308,
    0.4967,
    0.5075,
    0.4508,
    0.3728,
    0.2270,
    0.3369,
]
months = [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "May",
    "Jun",
    "Jul",
    "Aug",
    "Sep",
    "Oct",
    "Nov",
    "Dec",
]
best_threshold = [0.55, 0.44, 0.43, 0.39, 0.36, 0.39, 0.4, 0.36, 0.41, 0.42, 0.59, 0.67]

fig = plt.figure(num=None, figsize=(10, 7), dpi=300, facecolor="w", edgecolor="k")
ax = plt.gca()
fs = 14

color1 = "orange"
color2 = "red"
color3 = "blue"
(csiLineDay,) = ax.plot(
    range(len(months)),
    CSIday,
    linestyle="solid",
    color=color2,
    lw=4.0,
    marker="o",
    markersize=8,
)
(csiLineNight,) = ax.plot(
    range(len(months)),
    CSInight,
    linestyle="solid",
    color=color3,
    lw=4.0,
    marker="o",
    markersize=8,
)
(threshLine,) = ax.plot(
    range(len(months)),
    best_threshold,
    linestyle="solid",
    color=color1,
    lw=2.0,
    marker="o",
    markersize=5,
)

xticklabels = months
ax.set_ylim(0.1, 0.8)
ax.set_xlim(-0.5, len(months) - 0.5)
ax.set_xticks(range(len(months)))
ax.set_xticklabels(months, fontsize=fs)
plt.xticks(fontsize=fs)
ax.yaxis.grid(True, linestyle=":")
ax.xaxis.grid(True, linestyle=":")
ax.set_ylabel("Score or prob. thresh.", fontsize=fs + 2)
ax.set_xlabel("Month", fontsize=fs + 2)
plt.yticks(fontsize=fs)
plt.title("Best CSI and probability threshold", fontsize=fs + 6)
labs = ["CSI (day)", "CSI (night)", "Prob. thresh."]
leg = ax.legend(
    [csiLineDay, csiLineNight, threshLine], labs, fontsize=fs, loc=(0.01, 0.80)
)

# plt.show()
plt.savefig("goes_east_conus_by_month.png", format="png", bbox_inches="tight")
