import glob
import numpy as np
import os, sys
import pickle
import matplotlib.pyplot as plt
import cartopy.crs as ccrs
import cartopy.feature as cfeature
import netCDF4

files = glob.glob(
    "/ships19/grain/jcintineo/GLM/goes_east/CONUS/2020/20200[1-2]*/LT/noltg_30min/ltg_score_dict.pkl"
) + glob.glob(
    "/ships19/grain/jcintineo/GLM/goes_east/CONUS/2020/202012*/LT/noltg_30min/ltg_score_dict.pkl"
)

# aggregate LTs for each (i,j) point
for ii, f in enumerate(files):
    print(f)
    data_dict = pickle.load(open(f, "rb"))
    thresholds = data_dict["thresholds"]
    if ii == 0:
        spatial_leadtimes = data_dict[
            "spatial_leadtimes"
        ]  # a dictionary with keys as (i,j) points,
        # each point is a dict with thresholds,
        # each threshold key points to a list
    else:
        tmp = data_dict["spatial_leadtimes"]
        for k in tmp:

            if k in spatial_leadtimes:
                for th in spatial_leadtimes[k]:
                    spatial_leadtimes[k][th] += tmp[k][th]
            else:  # add new (i,j) points/keys
                spatial_leadtimes[k] = tmp[k]


##Place leadtimes in right geographic location##

pixbuff = 5
stride = 40
# CONUS data is shape=(1500,2500)
ny = 1500
nx = 2500
# take into account pixbuff on front and back ends
Ys = np.arange(pixbuff, ny - pixbuff, stride)
Xs = np.arange(pixbuff, nx - pixbuff, stride)
avg_leadtimes = np.zeros((len(thresholds), len(Ys), len(Xs)))

for k in spatial_leadtimes:
    # find the right indexes in all_leadtimes
    abiY, abiX = k
    Y = abiY // stride
    X = abiX // stride
    for ii, th in enumerate(thresholds):
        if len(spatial_leadtimes[k][th]):
            avg_leadtimes[ii, Y, X] = np.mean(spatial_leadtimes[k][th])
        # except: pass


##Make image##

nc = netCDF4.Dataset("static/GOES_East.nc")
gip = nc.variables["goes_imager_projection"]
x = nc.variables["x"][:]
y = nc.variables["y"][:]
# p = Proj('+proj=geos +lon_0='+str(gip.longitude_of_projection_origin)+\
#        ' +h='+str(gip.perspective_point_height)+' +x_0=0.0 +y_0=0.0 +a=' + \
#        str(gip.semi_major_axis) + ' +b=' + str(gip.semi_minor_axis))
x *= gip.perspective_point_height
y *= gip.perspective_point_height
geoproj = ccrs.Geostationary(
    central_longitude=gip.longitude_of_projection_origin,
    sweep_axis=gip.sweep_angle_axis,
    satellite_height=gip.perspective_point_height,
)

vmin = 5
vmax = 30
vinc = 5
fs = 16
fig = plt.figure(figsize=(10, 7))
ax = fig.add_axes([0, 0, 1, 1], projection=geoproj)
extent = [x[Xs].min(), x[Xs].max(), y[Ys].min(), y[Ys].max()]
ax.set_extent(extent, crs=geoproj)
img = ax.imshow(
    avg_leadtimes[3],
    extent=extent,
    transform=geoproj,
    vmin=vmin,
    vmax=vmax,
    cmap=plt.get_cmap("viridis"),
)
cbar = plt.colorbar(
    img,
    orientation="horizontal",
    pad=0.01,
    extend="both",
    drawedges=0,
    ax=ax,
    ticks=np.arange(vmin, vmax + 1, vinc),
)
cbar.set_label("Mean lead-time [min]", fontsize=fs)
cbar.ax.tick_params(labelsize=fs)

state_borders = cfeature.STATES.with_scale("50m")
ax.add_feature(state_borders, facecolor="none", edgecolor="black", linewidth=1.5)
ax.coastlines(color="black", linewidth=1.5)
plt.title("LightingCast lead-time at 30% threshold", fontsize=fs + 2)

plt.savefig("LC_AvgLT_30%_DJF.png", bbox_inches="tight")
